<?php defined('SYSPATH') or die('No direct script access.');

class Controller_Admin_Roles extends Controller_Admin_Layout_Secure {

	/**
	 * Roles List Action
	 */
	public function action_index()
	{
		// Load roles list query
		$roles = ORM::factory('role')
			->reset(FALSE);

		// Create pagination object
		$pagination = Pagination::factory(array(
			'group' => 'admin',
			'total_items' => $roles->count_all(),
		));

		// Modify role list query
		$roles = $roles
			->order_by('name', 'ASC')
			->offset($pagination->offset)
			->limit($pagination->items_per_page)
			->find_all();

		// Set content template
		$this->template->set('content', View::factory('admin/roles/list', array(
			'items' => $roles,
			'pagination' => $pagination,
		)));
	}

	/**
	 * Delete role action
	 */
	public function action_delete()
	{
		// Get role id
		$role_id = $this->request->param('id');
		if (!$role_id)
		{
			throw new HTTP_Exception_404('Role not found.');
		}

		// Get role
		$role = ORM::factory('role', $role_id);
		if (!$role->loaded())
		{
			throw new HTTP_Exception_404('Role not found.');
		}

		// Set message
		Session::instance()
			->set('message', __('Role :role deleted successfully.', array(':role' => $role->name)))
			->set('message_type', 'success');

		// Delete role
		$role->delete();

		// Redirect to base page
		$this->request->redirect($this->request->referrer());
	}

	public function action_new()
	{
		// New role
		$role = ORM::factory('role');

		// Set content template
		$this->template->set('content', View::factory('admin/roles/new', array(
			'item' => $role->as_array(),
		)));
	}

	public function action_edit()
	{
		// Get role id
		$role_id = $this->request->param('id');
		if (!$role_id)
		{
			throw new HTTP_Exception_404('Role not found.');
		}

		// Get role
		$role = ORM::factory('role', $role_id);
		if (!$role->loaded())
		{
			throw new HTTP_Exception_404('Role not found.');
		}

		// Set content template
		$this->template->set('content', View::factory('admin/roles/edit', array(
			'item' => $role->as_array(),
		)));
	}

	public function action_save()
	{
		// Protect page
		if ($this->request->method() !== Request::POST)
		{
			throw new HTTP_Exception_404('Page not found.');
		}

        // Back
        if ($this->request->post('back'))
        {
            $this->request->redirect('/admin/roles');
        }

		// create and configure form validation
		$post = Validation::factory($this->request->post())
			->labels(array(
				'name' => __('Name'),
				'description' => __('Description'),
			))
			->rule('name', 'not_empty');

		// check validation
		if ($post->check())
		{
			/** @var Model_Role $role **/
			$role = ORM::factory('role', Arr::get($post->data(), 'id'));

			// update role
			$role->values($post->data(), array('name', 'description', ))->save();

			// message
			Session::instance()
				->set('message', Arr::get($post->data(), 'id') ? 'Role updated successfully.' : 'Role created successfully.')
				->set('message_type', 'success');

			// redirect to list page
			$this->request->redirect(URL::site('/admin/roles'));
		}

		// Errors list
		View::set_global('errors', $post->errors('validation'));

		// Set content template
		$this->template->set('content', View::factory('admin/roles/' . (Arr::get($post->data(), 'id') ? 'edit' : 'new'),
			array('item' => $post->data(),)
		));
	}
} // End Admin Roles
