<?php defined('SYSPATH') or die('No direct script access.');

class Controller_Admin_Tags extends Controller_Admin_Layout_Secure {

    /**
     * Tags List Action
     */
    public function action_index()
    {
        // Load tags list query
        $items = ORM::factory('tag')
            ->reset(FALSE);

        // Create pagination object
        $pagination = Pagination::factory(array(
            'group' => 'admin',
            'total_items' => $items->count_all(),
        ));

        // Modify tags list query
        $items = $items
            ->order_by('tag', 'ASC')
            ->offset($pagination->offset)
            ->limit($pagination->items_per_page)
            ->find_all();

        // Set content template
        $this->template->set('content', View::factory('admin/tags/list', array(
            'items' => $items,
            'pagination' => $pagination,
        )));
    }

    /**
     * Delete tag action
     */
    public function action_delete()
    {
        // Get tag id
        $item_id = $this->request->param('id');
        if (! $item_id)
        {
            throw new HTTP_Exception_404('Tag not found.');
        }

        // Get tag
        $item = ORM::factory('tag', $item_id);
        if (! $item->loaded())
        {
            throw new HTTP_Exception_404('Tag not found.');
        }

        // Set message
        Session::instance()
            ->set('message', __('Tag :item deleted successfully.', array(':item' => $item->tag)))
            ->set('message_type', 'success');

        // Delete tag
        $item->delete();

        // Redirect to base page
        $this->request->redirect($this->request->referrer());
    }

    /**
     * Create tag action
     */
    public function action_new()
    {
        // New tag
        $item = ORM::factory('tag');

        // Set content template
        $this->template->set('content', View::factory('admin/tags/new', array(
            'item' => $item->as_array(),
        )));
    }

    /**
     * Edit tag action
     *
     * @throws HTTP_Exception_404
     */
    public function action_edit()
    {
        // Get tag id
        $item_id = $this->request->param('id');
        if (! $item_id)
        {
            throw new HTTP_Exception_404('Tag not found.');
        }

        // Get tag
        $item = ORM::factory('tag', $item_id);
        if (! $item->loaded())
        {
            throw new HTTP_Exception_404('Tag not found.');
        }

        // Set content template
        $this->template->set('content', View::factory('admin/tags/edit', array(
            'item' => $item->as_array(),
        )));
    }

    /**
     * Save tag action
     *
     * @throws HTTP_Exception_404
     */
    public function action_save()
    {
        // Protect page
        if ($this->request->method() !== Request::POST)
        {
            throw new HTTP_Exception_404('Page not found.');
        }

        // Back
        if ($this->request->post('back'))
        {
            $this->request->redirect('/admin/tags');
        }

        // create and configure form validation
        $post = Validation::factory($this->request->post())
            ->labels(array(
                'tag' => __('Tag'),
            ))
            ->rule('tag', 'not_empty');

        // check validation
        if ($post->check())
        {
            // store
            $data = $post->data();

            /** @var Model_Tag $item **/
            $item = ORM::factory('tag', Arr::get($data, 'id'));

            // update tag
            $item->values($data, array('tag', ))->save();

            // message
            Session::instance()
                ->set('message', __(Arr::get($post->data(), 'id') ? 'Tag updated successfully.' : 'Tag created successfully.'))
                ->set('message_type', 'success');

            // redirect to list page
            $this->request->redirect(URL::site('/admin/tags'));
        }

        // Errors list
        View::set_global('errors', $post->errors('validation'));

        // Set content template
        $this->template->set('content', View::factory('admin/tags/' . (Arr::get($post->data(), 'id') ? 'edit' : 'new'),
            array(
                'item' => $post->data(),
            )
        ));
    }
} // End Admin Tags